Method: Debugger::SkipCommand.help
- Defined in:
- lib/ruby-debug/commands/skip.rb
.help(cmd) ⇒ Object
24 25 26 27 28 29 30 31 32 |
# File 'lib/ruby-debug/commands/skip.rb', line 24 def help(cmd) %{ sk[ip]\tskip the next thrown exception This is useful if you've explicitly caught an exception through the "catch" command, and wish to pass the exception on to the code that you're debugging. } end |